@@ -27,10 +27,16 @@ class ApiRoot(APIView):
     -H "Accept: application/json; indent=4"`
     """
     def get(base_view, request, format=None):
-        relations = ['base']
+        relations = [
+            ('base', 'http://confine-project.eu/rel/server/base'),
+            ('api-token-auth', 'http://confine-project.eu/rel/controller/do-get-auth-token')
+        ]
+        # http://confine-project.eu/rel/server like resources
         for model in api._registry:
             name = force_unicode(model._meta.verbose_name)
-            relations.append(name if is_singleton(model) else '%s-list' % name)
+            name = name if is_singleton(model) else '%s-list' % name
+            rel = 'http://confine-project.eu/rel/server/%s' % name
+            relations.append((name, rel))
         headers = {'Link': link_header(relations, request)}
         return Response({}, headers=headers)
 
@@ -84,12 +90,12 @@ class RestApi(object):
         autodiscover('api')
         autodiscover('serializers')
     
-    def aggregate(self, model, field, name):
+    def aggregate(self, model, field, name, **kwargs):
         """ Dynamically add new fields to an existing serializer """
         # TODO provide support for hooking with nested serializers
         if model in self._registry:
-            self._registry[model][0].serializer_class.base_fields.update({name: field()})
-            self._registry[model][1].serializer_class.base_fields.update({name: field()})
+            self._registry[model][0].serializer_class.base_fields.update({name: field(**kwargs)})
+            self._registry[model][1].serializer_class.base_fields.update({name: field(**kwargs)})
     
 
 # singleton
