@@ -20,15 +20,21 @@ class Firmware(generics.RetrieveUpdateDestroyAPIView):
     rel = 'http://confine-project.eu/rel/controller/firmware'
     serializer_class = FirmwareSerializer
     model = Build
+    list = False
     
     def post(self, request, pk, *args, **kwargs):
         node = get_object_or_404(Node, pk=pk)
-        if request.DATA is None:
+        if not request.DATA:
             config = get_object_or_404(Config)
             base_image = config.get_images(node).order_by('default')[0]
-            build = Build.build(node, base_image, async=True)
+            async = True
+            success_status = status.HTTP_202_ACCEPTED
+            if '201-created' == request.META.get('HTTP_EXPECT', None):
+                async = False
+                success_status = status.HTTP_201_CREATED
+            build = Build.build(node, base_image, async=async)
             serializer = self.serializer_class(build, data=request.DATA)
-            return Response(serializer.data, status=status.HTTP_201_CREATED)
+            return Response(serializer.data, status=success_status)
         raise exceptions.ParseError(detail='This endpoint only accepts null data')
 
 
