@@ -1,4 +1,4 @@
-from os import path
+import os
 
 from django import forms
 
@@ -46,8 +46,10 @@ class AuthKeysPlugin(FirmwarePlugin):
         auth_keys = kwargs.get('auth_keys', '')
         context = {
             'auth_keys': auth_keys,
-            'auth_keys_path': path.join(image.mnt, 'etc/dropbear/authorized_keys')
+            'auth_keys_path': os.path.join(image.mnt, 'etc/dropbear/authorized_keys')
         }
         run('echo "%(auth_keys)s" > %(auth_keys_path)s' % context)
-        run('chown root:root %(auth_keys_path)s' % context)
+        os.chown(context['auth_keys_path'], 0, 0)
+        key_stat = os.stat(context['auth_keys_path'])
+        assert 0 == key_stat.st_uid == key_stat.st_gid, "Failing when changing ownership!"
         run('chmod 0600 %(auth_keys_path)s' % context)
