@@ -5,7 +5,7 @@ from celery.task import task
 
 from controller.models.utils import get_file_field_base_path
 
-from firmware.image import Image
+from .image import Image
 
 
 def update_state(build, progress, next, description):
@@ -85,4 +85,4 @@ def build(build_id, *args, **kwargs):
     
     build_obj.image = dest_path
     build_obj.save()
-    return { 'progress': 99, 'description': 'Redirecting', 'result': dest_path }
+    return { 'progress': 100, 'description': 'Redirecting', 'result': dest_path }
