@@ -57,18 +57,18 @@ class UsersIterator(forms.models.ModelChoiceIterator):
 
     def __iter__(self):
         yield ('', '---------')
-        users = User.objects.all().order_by('username')
+        users = User.objects.exclude(is_active=False).order_by('name')
         superusers = users.filter(is_superuser=True)
         if superusers:
-            yield ('Operators', list(superusers.values_list('pk', 'username')))
+            yield ('Operators', list(superusers.values_list('pk', 'name')))
             users = users.exclude(is_superuser=True)
         if self.ticket and self.ticket.group:
             group = users.filter(groups=self.ticket.group)
             if group:
-                yield ('Group', list(group.values_list('pk', 'username')))
+                yield ('Group', list(group.values_list('pk', 'name')))
                 users = users.exclude(groups=self.ticket.group)
         if users:
-            yield ('Other', list(users.values_list('pk', 'username')))
+            yield ('Other', list(users.values_list('pk', 'name')))
 
 
 class TicketForm(forms.ModelForm):
@@ -90,7 +90,7 @@ class TicketForm(forms.ModelForm):
             user_choices = UsersIterator()
         else:
             description = markdown(ticket.description)
-            # some heuristics for better line breaking
+            # some hacks for better line breaking
             description = description.replace('>\n', '#Ha9G9-?8')
             description = description.replace('\n', '<br>')
             description = description.replace('#Ha9G9-?8', '>\n')
@@ -98,7 +98,8 @@ class TicketForm(forms.ModelForm):
             widget = ReadOnlyWidget(description, description)
             self.fields['display_description'].widget = widget
             user_choices = UsersIterator(ticket=ticket)
-        self.fields['owner'].choices = user_choices
+        if 'owner' in self.fields:
+            self.fields['owner'].choices = user_choices
     
     def clean_description(self):
         """  clean HTML tags """
