@@ -5,7 +5,7 @@ from django.contrib import admin, messages
 from django.template.response import TemplateResponse
 
 from controller.admin import ChangeListDefaultFilter
-from controller.admin.utils import insertattr, admin_link, get_modeladmin, wrap_admin_view
+from controller.admin.utils import insertattr, admin_link, wrap_admin_view
 from controller.forms.widgets import ReadOnlyWidget
 from nodes.models import Node, Server
 from permissions.admin import (PermissionGenericTabularInline, PermissionTabularInline,
@@ -43,19 +43,19 @@ class TincHostInline(PermissionGenericTabularInline):
             return ['pubkey'] + readonly_fields
         return readonly_fields
     
-    def get_fieldsets(self, request, obj=None):
+    def get_formset(self, request, obj=None, **kwargs):
         """ Warning user if the tinc host is not fully configured """
-        if obj and not obj.tinc.pubkey:
+        if obj and not obj.tinc.pubkey and request.method == 'GET':
             msg = 'This %s misses a tinc public key.' % obj._meta.verbose_name
             messages.warning(request, msg)
-        return super(TincHostInline, self).get_fieldsets(request, obj=obj)
+        return super(TincHostInline, self).get_formset(request, obj=obj, **kwargs)
 
 
 class TincClientInline(TincHostInline):
     model = TincClient
     verbose_name_plural = 'tinc client'
     form = TincClientInlineForm
-    
+
 
 class TincServerInline(TincHostInline):
     # TODO TincAddress nested inlines: https://code.djangoproject.com/ticket/9025
@@ -138,7 +138,7 @@ class HostAdmin(ChangeListDefaultFilter, PermissionModelAdmin):
             # ronly forms doesn't have initial
             user = request.user
             if not user.is_superuser:
-                ro_widget = ReadOnlyWidget(user.id, user.username)
+                ro_widget = ReadOnlyWidget(user.id, user.get_username())
                 form.base_fields['owner'].widget = ro_widget
                 form.base_fields['owner'].required = False
             else:
@@ -163,5 +163,3 @@ admin.site.register(Gateway, GatewayAdmin)
 
 insertattr(Node, 'inlines', TincClientInline, weight=-5)
 insertattr(Server, 'inlines', TincServerInline)
-
-node_modeladmin = get_modeladmin(Node)
