@@ -16,6 +16,15 @@ def validate_sliver_mac_prefix(value):
         raise ValidationError('%s is not a 16-bit integer number in hex' % value)
 
 
+def validate_priv_ipv4_prefix(value):
+    try:
+        ip = IP(value)
+    except:
+        raise ValidationError('"%s" is not a IPv4/24 private network' % value)
+    if ip.version() != 4 or ip.strNetmask() != '255.255.255.0' or ip.iptype() != 'PRIVATE':
+        raise ValidationError('"%s" is not a IPv4/24 private network' % ip)
+
+
 def validate_ipv4_range(value):
     try: 
         ip, offset = value.split('#')
@@ -39,12 +48,14 @@ def validate_csr(csr, node):
         csr = X509.load_request_string(str(csr))
     except:
         raise ValidationError('Not a valid CSR')
-    
     subject = csr.get_subject()
-    if not subject.CN or node.mgmt_net.addr != IP(subject.CN):
-        raise ValidationError("Common Name (CN) must be equeal than the "\
-            "node management address: %s != %s" % (subject.CN, node.mgmt_net.addr))
-    
-    if not Group.objects.filter(nodes=node, roles__user__email=subject.emailAddress, roles__is_admin=True).exists():
-        raise ValidationError("No admin with '%s' email address for this node." % subject.emailAddress)
-
+    if not subject.CN:
+        raise ValidationError("Required subject Common Name (CN) not provided")
+    try:
+        cnip = IP(subject.CN)
+    except ValueError:
+        msg = "Subject Common Name (CN) '%s' is not a valid IP address"
+        raise ValidationError(msg % subject.CN)
+    if node.mgmt_net.addr != cnip:
+        msg = "Common Name (CN) must be equeal to node management address: '%s' != '%s'"
+        raise ValidationError(msg % (subject.CN, node.mgmt_net.addr))
