@@ -4,6 +4,7 @@ from django.contrib.admin.templatetags.admin_list import _boolean_icon
 from controller.forms.widgets import ShowText
 from nodes.models import Node
 
+from .helpers import state_value
 from .models import Slice, Sliver
 
 
@@ -46,6 +47,17 @@ class SliceAdminForm(forms.ModelForm):
         # ! Register state: return the old value
         return self.initial["vlan_nr"]
 
+class SliverAdminForm(forms.ModelForm):
+    def __init__(self, *args, **kwargs):
+        """ Improve user interface: form style and empty labels """
+        # FIXME: Works but is NOT called: see SliverAdmin at admin.py
+        super(SliverAdminForm, self).__init__(*args, **kwargs)
+        if self.instance:
+            sliver_state = state_value(self.instance.set_state)
+            slice_state = state_value(self.instance.slice.set_state)
+            if sliver_state > slice_state:
+                self.fields['set_state'].widget.attrs = {'class': 'warning'}
+
 
 class SliceSliversForm(forms.ModelForm):
     def __init__(self, *args, **kwargs):
@@ -83,13 +95,13 @@ class SliverIfaceInlineForm(forms.ModelForm):
             self.fields['parent'].queryset = self.node.direct_ifaces
             # Hook slice for future processing on iface.model_clean()
             self.instance.slice = self.slice
-        # Remove unallowed iface types from choices
-        queryset = Node.objects.filter(pk=self.node.id)
-        choices = self.fields['type'].choices
-        for iface_type, iface_object in Sliver.get_registered_ifaces().items():
-            if not iface_object.is_allowed(self.slice, queryset):
-                choices = [choice for choice in choices if choice[0] != iface_type]
-        self.fields['type'].choices = choices
+            # Remove unallowed iface types from choices
+            queryset = Node.objects.filter(pk=self.node.id)
+            choices = self.fields['type'].choices
+            for iface_type, iface_object in Sliver.get_registered_ifaces().items():
+                if not iface_object.is_allowed(self.slice, queryset):
+                    choices = [choice for choice in choices if choice[0] != iface_type]
+            self.fields['type'].choices = choices
 
 
 class SliverIfaceBulkForm(forms.Form):
