@@ -11,7 +11,7 @@ from django.utils.timezone import now
 from controller.models.fields import MultiSelectField, NullableCharField
 from controller.utils import autodiscover
 from controller.core.validators import (validate_net_iface_name, validate_prop_name,
-        validate_sha256, validate_file_extensions)
+        validate_sha256, validate_file_extensions, validate_name)
 from nodes.models import Node
 from nodes.settings import NODES_NODE_ARCHS
 
@@ -26,6 +26,22 @@ def get_expires_on():
     return now() + settings.SLICES_SLICE_EXP_INTERVAL
 
 
+def clean_sha256(self, fields):
+    for field_name in fields:
+        if getattr(self, field_name+'_uri') and not getattr(self, field_name+'_sha256'):
+            raise ValidationError('Missing %s_sha256.' % field_name)
+
+
+def set_sha256(self, fields):
+    for field_name in fields:
+        field = getattr(self, field_name)
+        if field and field.file:
+            # TODO chunked for saving some memory?
+            sha256 = hashlib.sha256(field.file.read()).hexdigest()
+            field.file.seek(0)
+            setattr(self, field_name+'_sha256', sha256)
+
+
 def make_upload_to(field_name, base_path, file_name):
     """ dynamically generate file names with randomnes for upload_to args """
     def upload_path(instance, filename, base_path=base_path, file_name=file_name,
@@ -63,8 +79,7 @@ class Template(models.Model):
             help_text='The unique name of this template. A single line of free-form '
                       'text with no whitespace surrounding it, it can include '
                       'version numbers and other information.',
-            validators=[validators.RegexValidator('^\w[\s\w.@+-]+\w$',
-                       'Enter a valid name.', 'invalid')])
+            validators=[validate_name])
     description = models.TextField(blank=True,
             help_text='An optional free-form textual description of this template.')
     type = models.CharField(max_length=32, choices=settings.SLICES_TEMPLATE_TYPES,
@@ -84,16 +99,27 @@ class Template(models.Model):
             upload_to=make_upload_to('image', settings.SLICES_TEMPLATE_IMAGE_DIR,
                                      settings.SLICES_TEMPLATE_IMAGE_NAME),
             validators=[validate_file_extensions(settings.SLICES_TEMPLATE_IMAGE_EXTENSIONS)])
+    image_uri = models.CharField('image URI', max_length=256, blank=True,
+            help_text='The URI of a file containing an image for slivers (if they '
+                      'do not explicitly indicate one). The file must be an archive '
+                      '(e.g. a .tar.gz) of the upper directory of an overlayfs filesystem, '
+                      'and will be applied on top of the used template. This member '
+                      'may be set directly or through the do-upload-overlay function.')
+    image_sha256 = models.CharField('image SHA256', max_length=64, blank=True,
+            help_text='The SHA256 hash of the image file, used to check its integrity. '
+                      'Compulsory when a file has been specified.',
+            validators=[validate_sha256])
     
     def __unicode__(self):
         return "%s (%s)" % (self.name, self.type)
     
-    @property
-    def image_sha256(self):
-        try:
-            return hashlib.sha256(self.image.file.read()).hexdigest()
-        except:
-            return None
+    def clean(self):
+        super(Template, self).clean()
+        clean_sha256(self, ('image',))
+    
+    def save(self, *args, **kwargs):
+        set_sha256(self, ('image',))
+        super(Template, self).save(*args, **kwargs)
 
 
 class Slice(models.Model):
@@ -111,8 +137,7 @@ class Slice(models.Model):
     name = models.CharField(max_length=64, unique=True,
             help_text='A unique name of this slice. A single non-empty line of free-form '
                       'text with no whitespace surrounding it.',
-            validators=[validators.RegexValidator('^\w[\s\w.@+-]+\w$',
-                       'Enter a valid name.', 'invalid')])
+            validators=[validate_name])
     description = models.TextField(blank=True,
             help_text='An optional free-form textual description of this slice.')
     expires_on = models.DateField(null=True, blank=True, default=get_expires_on,
@@ -173,7 +198,7 @@ class Slice(models.Model):
                       'See <a href="https://wiki.confine-project.eu/arch:'
                       'slice-sliver-states">slice and sliver states</a> for the full '
                       'description of set states and possible transitions.')
-    template = models.ForeignKey(Template,
+    template = models.ForeignKey(Template, limit_choices_to={'is_active':True},
             help_text='The template to be used by the slivers of this slice (if they '
                       'do not explicitly indicate one).')
     group = models.ForeignKey('users.Group', related_name='slices')
@@ -200,18 +225,12 @@ class Slice(models.Model):
         if not self.pk:
             self.expires_on = now() + settings.SLICES_SLICE_EXP_INTERVAL
             save_files_with_pk_value(self, ('exp_data', 'overlay'), *args, **kwargs)
+        set_sha256(self, ('exp_data', 'overlay'))
         super(Slice, self).save(*args, **kwargs)
     
     def clean(self):
         super(Slice, self).clean()
-        for field in ('exp_data', 'overlay'):
-            if getattr(self, field):
-                if getattr(self, field+'_uri'):
-                    raise ValidationError('%s or %s_uri ?' % (field, field))
-                sha256 = hashlib.sha256(getattr(self, field).file.read()).hexdigest()
-                setattr(self, field+'_sha256', sha256)
-            if getattr(self, field+'_uri') and not getattr(self, field+'_sha256'):
-                raise ValidationError('Missing %s_sha256.' % field)
+        clean_sha256(self, ('exp_data', 'overlay'))
         # clean set_state
         if not self.pk:
             if self.set_state != Slice.REGISTER:
@@ -241,7 +260,7 @@ class Slice(models.Model):
     
     def _get_vlan_nr(self):
         qset = Slice.objects.exclude(vlan_nr=None).order_by('-vlan_nr')
-        last_nr = qset[0].vlan_nr if qset else 0
+        last_nr = qset.first().vlan_nr if qset else 0
         if last_nr < self.min_vlan_nr:
             return self.min_vlan_nr
         if last_nr >= self.max_vlan_nr:
@@ -332,6 +351,7 @@ class Sliver(models.Model):
                       'slice-sliver-states">slice and sliver states</a> for the full '
                       'description of set states and possible transitions.', null=True)
     template = models.ForeignKey(Template, null=True, blank=True,
+            limit_choices_to={'is_active':True},
             help_text='If present, the template to be used by this sliver, instead '
                       'of the one specified by the slice.')
     
@@ -345,14 +365,7 @@ class Sliver(models.Model):
     
     def clean(self):
         super(Sliver, self).clean()
-        for field in ('exp_data', 'overlay'):
-            if getattr(self, field):
-                if getattr(self, field+'_uri'):
-                    raise ValidationError('%s or %s_uri ?' % (field, field))
-                sha256 = hashlib.sha256(getattr(self, field).file.read()).hexdigest()
-                setattr(self, field+'_sha256', sha256)
-            if getattr(self, field+'_uri') and not getattr(self, field+'_sha256'):
-                raise ValidationError('Missing %s_sha256.' % field)
+        clean_sha256(self, ('exp_data', 'overlay'))
         # TODO can slivers be added to slice.set_state != Register?
 #        if self.set_state:
 #            slice = self.slice
@@ -366,6 +379,7 @@ class Sliver(models.Model):
         if not self.pk:
             self.instance_sn = self.slice.new_sliver_instance_sn
             save_files_with_pk_value(self, ('exp_data', 'overlay'), *args, **kwargs)
+        set_sha256(self, ('exp_data', 'overlay'))
         super(Sliver, self).save(*args, **kwargs)
     
     @property
@@ -385,6 +399,11 @@ class Sliver(models.Model):
     def mgmt_iface(self):
         iface = self.interfaces.filter(type='management')
         return iface.get() if iface else None
+
+    @property
+    def api_id(self):
+        """ The unique ID of this sliver (REST-API) """
+        return "%i@%i" % (self.slice.id, self.node.id)
     
     def update(self):
         self.instance_sn += 1
@@ -467,7 +486,6 @@ class SliverIface(models.Model):
     
     class Meta:
         unique_together = ('sliver', 'name')
-        ordering = ['nr']
         verbose_name = 'sliver interface'
         verbose_name_plural = 'sliver interfaces'
     
@@ -523,7 +541,7 @@ class SliverIface(models.Model):
         # TODO use sliver_pub_ipv{4,6}_range/avail/total for PUBLIC{4,6}
         if not SliverIface.objects.filter(sliver=self.sliver).exists():
             return 1
-        last_nr = SliverIface.objects.filter(sliver=self.sliver).order_by('-nr')[0].nr
+        last_nr = SliverIface.objects.filter(sliver=self.sliver).order_by('-nr').first().nr
         if last_nr >= self.max_nr:
             # try to recycle old values
             for new_nr in range(1, self.max_nr):
