@@ -3,7 +3,7 @@ from __future__ import absolute_import
 from django import forms
 from django.contrib import admin
 from django.contrib.auth.models import Group as AuthGroup
-from django.contrib.auth.admin import UserAdmin
+from django.contrib.auth.admin import UserAdmin as AuthUserAdmin
 from django.core.urlresolvers import reverse, resolve
 from django.db import models
 from django.utils.safestring import mark_safe
@@ -41,7 +41,7 @@ class GroupRolesInline(PermissionTabularInline, SortableTabularInline):
     extra = 0
     formset = GroupRolesFormSet
     form = GroupRolesInlineForm
-    sortable_fields = {'user': 'user__username'}
+    sortable_fields = {'user': 'user__name'}
     verbose_name = 'member'
     verbose_name_plural = 'members'
     
@@ -127,10 +127,9 @@ class JoinRequestInline(PermissionTabularInline):
         return super(JoinRequestInline, self).get_formset(request, obj=obj, **kwargs)
 
 
-class UserAdmin(UserAdmin, PermissionModelAdmin):
+class UserAdmin(AuthUserAdmin, PermissionModelAdmin):
     list_display = (
-        'username', 'email', 'first_name', 'last_name', 'group_links', 
-        'is_superuser', 'is_active'
+        'name', 'email', 'group_links', 'is_superuser', 'is_active'
     )
     list_filter = (
         'is_active', 'is_superuser', 'roles__is_admin', 'roles__is_researcher',
@@ -138,8 +137,7 @@ class UserAdmin(UserAdmin, PermissionModelAdmin):
     )
     fieldsets = (
         (None, {'fields': ('username', )}),
-        ('Personal info', {'fields': ('first_name', 'last_name', 'email',
-                                      'description',)}),
+        ('Personal info', {'fields': ('name', 'email', 'description',)}),
         ('Permissions', {'fields': ('is_active', 'is_superuser',)}),
         ('Important dates', {
             'classes': ('collapse',),
@@ -147,12 +145,12 @@ class UserAdmin(UserAdmin, PermissionModelAdmin):
         }),
     )
     add_fieldsets = (
-        (None, {
-            'classes': ('wide',),
-            'fields': ('username', 'password1', 'password2', 'email')}
-        ),)
+        (None, {'fields': ('username', 'password1', 'password2',), 'classes': ('wide',)}),
+        ('Personal info', {'fields': ('name', 'email',), 'classes': ('wide',)}),
+    )
     
-    search_fields = ('username', 'email', 'first_name', 'last_name')
+    search_fields = ('username', 'email', 'name')
+    ordering = ('name',)
     inlines = [AuthTokenInline, UserRolesInline]
     actions = [enable_account, send_email]
     sudo_actions = ['delete_selected', 'enable_account', 'send_email']
@@ -210,7 +208,7 @@ class GroupAdmin(ChangeViewActions, PermissionModelAdmin):
             if user.is_superuser or 'allow_%s' % resource in readonly_fields:
                 form.base_fields.pop('request_%s' % resource)
             else:
-                form.base_fields.pop('allow_%s' % resource)
+                form.base_fields.pop('allow_%s' % resource, None)
         # Hook request for sending emails on form.save
         form.__request__ = request
         return form
