@@ -12,8 +12,9 @@ from api import api, generics
 from controller.core.validators import validate_name
 from permissions.api import ApiPermissionsMixin
 
-from .models import User, Group
-from .serializers import UserSerializer, GroupSerializer
+from .models import User, Group, Roles
+from .serializers import (GroupSerializer, GroupCreateSerializer,
+    UserSerializer, UserCreateSerializer)
 
 
 class ChangeAuth(APIView):
@@ -59,24 +60,6 @@ class ChangeAuth(APIView):
             return Response(response_data, status=status.HTTP_200_OK)
         raise exceptions.ParseError(detail='Password value not provided')
 
-class ChangePassword(APIView):
-    """
-    ### DEPRECATED --> use instead `change-auth` function ###
-    **Relation type:** [`http://confine-project.eu/rel/controller/do-change-password`](
-        http://confine-project.eu/rel/controller/do-change-password)
-    
-    Endpoint containing the function URI used to change the user password.
-    
-    POST data: `New user password`
-    """
-    url_name = 'change-password'
-    rel = 'http://confine-project.eu/rel/controller/do-change-password'
-    
-    def post(self, request, *args, **kwargs):
-        response_data = {'error_detail': 'Use do-change-auth instead of '\
-            'deprecated and obsolete do-change-password.'}
-        return Response(response_data, status=status.HTTP_410_GONE)
-
 
 class UserList(ApiPermissionsMixin, generics.URIListCreateAPIView):
     """
@@ -88,8 +71,10 @@ class UserList(ApiPermissionsMixin, generics.URIListCreateAPIView):
     to them.
     """
     model = User
+    add_serializer_class = UserCreateSerializer
     serializer_class = UserSerializer
 #    filter_fields = ('username',)
+#    post_exclude = ('is_active', 'is_superuser', 'group_roles')
 
     def pre_save(self, obj):
         super(UserList, self).pre_save(obj)
@@ -106,7 +91,8 @@ class UserDetail(generics.RetrieveUpdateDestroyAPIView):
     """
     model = User
     serializer_class = UserSerializer
-    ctl = [ChangeAuth, ChangePassword]
+    ctl = [ChangeAuth]
+    fields_superuser = ['is_active', 'is_superuser']
 
 
 class GroupList(ApiPermissionsMixin, generics.URIListCreateAPIView):
@@ -117,26 +103,14 @@ class GroupList(ApiPermissionsMixin, generics.URIListCreateAPIView):
     This resource describes a group of users using the testbed.
     """
     model = Group
+    add_serializer_class = GroupCreateSerializer
     serializer_class = GroupSerializer
 #    filter_fields = ('username',)
+#    post_exclude = ('allow_nodes', 'allow_slices', 'user_roles')
     
-    def post(self, request, *args, **kwargs):
-        """ adds current request.user as default group admin """
-        # check if POST only has accepted data
-        for key in request.DATA.keys():
-            if key not in ['name', 'description', 'sfa']:
-                raise exceptions.ParseError(detail='Invalid extra data provided %s' % key)
-        # check if POST has required data
-        if 'name' not in request.DATA:
-            raise exceptions.ParseError(detail='Field "name" required')
-        # add the group creator as group admin
-        request.DATA['user_roles'] = [{
-            'user': {
-                'uri': reverse('user-detail', args=[request.user.pk], request=request)
-            },
-            'is_admin': True
-        }]
-        return super(GroupList, self).post(request, *args, **kwargs)
+    def post_save(self, obj, created=False):
+        """ user that creates a group becomes its admin """
+        Roles.objects.get_or_create(user=self.request.user, group=obj, is_admin=True)
 
 
 class GroupDetail(generics.RetrieveUpdateDestroyAPIView):
@@ -148,6 +122,7 @@ class GroupDetail(generics.RetrieveUpdateDestroyAPIView):
     """
     model = Group
     serializer_class = GroupSerializer
+    fields_superuser = ['allow_nodes', 'allow_slices']
 
 
 api.register(UserList, UserDetail)
