@@ -16,7 +16,7 @@ class UserCreationForm(forms.ModelForm):
     
     class Meta:
         model = User
-        fields = ('username', 'email')
+        fields = ('username', 'name', 'email')
     
     def clean_password2(self):
         # Check that the two password entries match
@@ -73,11 +73,16 @@ class UserRolesForm(forms.ModelForm):
                         display_value=mark_safe('<b>'+get_admin_link(instance.group)))
     
     def clean(self):
+        """ prevent groups without no admins """
         if not self.cleaned_data.get('is_admin'):
+            group = self.cleaned_data.get('group')
             role = self.instance
-            admins = Roles.objects.filter(group=role.group, is_admin=True).exclude(pk=role.pk)
-            if not admins.exists():
-                raise ValidationError('The group must have at least one admin')
+            # Adding roles is harmless and avoid to display this validation error
+            # when there is no group selected
+            if group and role.pk:
+                admins = Roles.objects.filter(group=group, is_admin=True).exclude(pk=role.pk)
+                if not admins.exists():
+                    raise ValidationError('The group must have at least one admin')
         return super(UserRolesForm, self).clean()
 
 
@@ -198,6 +203,7 @@ class JoinRequestForm(forms.ModelForm):
             modeladmin = get_modeladmin(Group)
             modeladmin.log_change(request, jrequest.group, log)
 
+
 class SendMailForm(forms.Form):
     subject = forms.CharField(widget=forms.TextInput(attrs={'size':'118'}))
     message = forms.CharField(widget=forms.Textarea(attrs={'cols': 118, 'rows': 15}))
