@@ -9,12 +9,22 @@ except ImportError:
 from captcha.fields import CaptchaField
 from registration.forms import RegistrationFormUniqueEmail as RegistrationForm
 
+
 class RegistrationFormUniqueEmail(RegistrationForm):
     """ 
     Since django registration v1.0 custom user class must define its ours
     form for custom models.
     See source of registration/forms.py?at=v1.0
     """
+    username = forms.CharField(required=False)
+    name = forms.CharField()
+
+    def __init__(self, *args, **kwargs):
+        """ Reorder form fields """
+        super(RegistrationFormUniqueEmail, self).__init__(*args, **kwargs)
+        self.fields.keyOrder.pop(self.fields.keyOrder.index('name'))
+        self.fields.keyOrder.insert(0, 'name')
+
     def clean_email(self):
         """
         Validate that the supplied email address is unique for the
@@ -25,6 +35,13 @@ class RegistrationFormUniqueEmail(RegistrationForm):
             raise forms.ValidationError(_("This email address is already in use. Please supply a different email address."))
         return self.cleaned_data['email']
 
+    def clean_name(self):
+        existing = User.objects.filter(name__iexact=self.cleaned_data['name'])
+        if existing.exists():
+            raise forms.ValidationError(_("A user with that name already exists."))
+        else:
+            return self.cleaned_data['name']
+
     def clean_username(self):
         """
         Validate that the username is alphanumeric and is not already
