@@ -22,7 +22,7 @@ DATABASES = {
 }
 
 # Enable persistent connections
-CONN_MAX_AGE = 60
+CONN_MAX_AGE = 60*10
 
 # Local time zone for this installation. Choices can be found here:
 # http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
@@ -152,7 +152,6 @@ INSTALLED_APPS = (
     'admin_tools.theming',
     'admin_tools.menu',
     'admin_tools.dashboard',
-    'django_orphaned',
     
     # Django.contrib
     'django.contrib.auth',
@@ -173,41 +172,14 @@ AUTHENTICATION_BACKENDS = [
     'users.auth.EmailBackend',
 ]
 
-# A sample logging configuration. The only tangible logging
-# performed by this configuration is to send an email to
-# the site admins on every HTTP 500 error when DEBUG=False.
-# See http://docs.djangoproject.com/en/dev/topics/logging for
-# more details on how to customize your logging configuration.
-LOGGING = {
-    'version': 1,
-    'disable_existing_loggers': False,
-    'filters': {
-        'require_debug_false': {
-            '()': 'django.utils.log.RequireDebugFalse'
-        }
-    },
-    'handlers': {
-        'mail_admins': {
-            'level': 'ERROR',
-            'filters': ['require_debug_false'],
-            'class': 'django.utils.log.AdminEmailHandler'
-        }
-    },
-    'loggers': {
-        'django.request': {
-            'handlers': ['mail_admins'],
-            'level': 'ERROR',
-            'propagate': True,
-        },
-    }
-}
-
 # Email config
 EMAIL_BACKEND = 'djcelery_email.backends.CeleryEmailBackend'
 
 # Storage configuration
 DEFAULT_FILE_STORAGE = 'controller.core.storage.DoubleExtensionAwareFileSystemStorage'
 
+# The numeric mode (i.e. 0644) to set newly uploaded files to
+FILE_UPLOAD_PERMISSIONS = 0644
 
 #################################
 ## 3RD PARTY APPS CONIGURATION ##
@@ -329,55 +301,6 @@ REST_FRAMEWORK = {
 USE_ETAGS = True
 
 
-LOGGING = {
-    'version': 1,
-    'disable_existing_loggers': True,
-    'formatters': {
-        'standard': {
-            'format' : "[%(asctime)s] %(levelname)s [%(name)s:%(lineno)s] %(message)s",
-            'datefmt' : "%d/%b/%Y %H:%M:%S"
-        },
-    },
-    'handlers': {
-        'null': {
-            'level':'DEBUG',
-            'class':'django.utils.log.NullHandler',
-        },
-        'logfile': {
-            'level':'DEBUG',
-            'class':'logging.handlers.RotatingFileHandler',
-            'filename': '/dev/null',
-            'maxBytes': 50000,
-            'backupCount': 2,
-            'formatter': 'standard',
-        },
-        'console':{
-            'level':'INFO',
-            'class':'logging.StreamHandler',
-            'formatter': 'standard'
-        },
-    },
-    'loggers': {
-        'django': {
-            'handlers':['console'],
-            'propagate': True,
-            'level':'WARN',
-        },
-        'django.db.backends': {
-            'handlers': ['console'],
-            'level': 'DEBUG',
-            'propagate': False,
-        },
-        'state.models': {
-#            'handlers': ['console', 'logfile'],
-            'handlers': ['console'],
-            'level': 'DEBUG',
-        },
-    }
-}
-
-
-
 ###################################
 ## CONTROLLER APPS CONFIGURATION ##
 ###################################
