@@ -4,6 +4,7 @@ import random
 import string
 from optparse import make_option
 
+from django.core.management import call_command
 from django.core.management.base import BaseCommand, CommandError
 
 from controller import get_version
@@ -27,6 +28,7 @@ class Command(BaseCommand):
     option_list = BaseCommand.option_list
     help = "Upgrading controller's installation"
     can_import_settings = False
+    leave_locale_alone = True
     
     @check_root
     def handle(self, *args, **options):
@@ -62,7 +64,10 @@ class Command(BaseCommand):
             eggs = eggs.stdout.splitlines()
             try:
                 if desired_version:
-                    r('pip install confine-controller==%s' % desired_version)
+                    # if desired_version == 'dev':
+                    #     r('pip install -e git+http://git.confine-project.eu/confine/controller.git@master#egg=confine-controller')
+                    # else:
+                        r('pip install confine-controller==%s' % desired_version)
                 else:
                     # Did I mentioned how I hate PIP?
                     if run('pip --version|cut -d" " -f2').stdout == '1.0':
@@ -92,4 +97,4 @@ class Command(BaseCommand):
         
         # version specific upgrade operations
         if not options.get('pip_only'):
-            run("python manage.py postupgradecontroller --from %s" % current_version)
+            call_command("postupgradecontroller", version=current_version)
